@@ -1,5 +1,5 @@
 # coding: utf-8
-from . import globalvar
+import sunday.core.globalvar as globalvar
 
 def cache_name(name):
     '''根据名称缓存第一次执行结果'''
@@ -9,4 +9,4 @@ def cache_name(name):
                 globalvar.setvar(name, func(*args, **kwargs))
             return globalvar.getvar(name)
         return wrap
-    return cache_name_func
\ No newline at end of file
+    return cache_name_func
