@@ -1,6 +1,6 @@
 # coding: utf-8
 import os
-from . import paths
+import sunday.core.paths as paths
 from configparser import ConfigParser
 
 __all__ = ['getConfig']
@@ -20,4 +20,4 @@ def getConfig(name, file='config.ini', default={}):
         if cfg.has_option(name, key):
             return cfg.get(name, key)
         return default.get(key) or defaultConfig.get('.'.join([name, key]))
-    return getval
\ No newline at end of file
+    return getval
